@@ -66,6 +66,9 @@ namespace xsimd
     {
     public:
 
+        using self_type = batch<int32_t, 16>;
+        using base_type = simd_batch<self_type>;
+
         batch();
         explicit batch(int32_t i);
         batch(int32_t i0, int32_t i1,  int32_t i2,  int32_t i3,  int32_t i4,  int32_t i5,  int32_t i6,  int32_t i7,
@@ -90,11 +93,11 @@ namespace xsimd
         batch& load_aligned(const double* src);
         batch& load_unaligned(const double* src);
 
-        batch& load_aligned(const char* src);
-        batch& load_unaligned(const char* src);
+        batch& load_aligned(const int8_t* src);
+        batch& load_unaligned(const int8_t* src);
 
-        batch& load_aligned(const unsigned char* src);
-        batch& load_unaligned(const unsigned char* src);
+        batch& load_aligned(const uint8_t* src);
+        batch& load_unaligned(const uint8_t* src);
 
         void store_aligned(int32_t* dst) const;
         void store_unaligned(int32_t* dst) const;
@@ -108,11 +111,16 @@ namespace xsimd
         void store_aligned(double* dst) const;
         void store_unaligned(double* dst) const;
 
-        void store_aligned(char* dst) const;
-        void store_unaligned(char* dst) const;
+        void store_aligned(int8_t* dst) const;
+        void store_unaligned(int8_t* dst) const;
 
-        void store_aligned(unsigned char* dst) const;
-        void store_unaligned(unsigned char* dst) const;
+        void store_aligned(uint8_t* dst) const;
+        void store_unaligned(uint8_t* dst) const;
+
+        using base_type::load_aligned;
+        using base_type::load_unaligned;
+        using base_type::store_aligned;
+        using base_type::store_unaligned;
 
         int32_t operator[](std::size_t index) const;
 
@@ -246,28 +254,28 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int32_t, 16>& batch<int32_t, 16>::load_aligned(const char* src)
+    inline batch<int32_t, 16>& batch<int32_t, 16>::load_aligned(const int8_t* src)
     {
         __m128i tmp = _mm_load_si128((const __m128i*)src);
         m_value = _mm512_cvtepi8_epi32(tmp);
         return *this;
     }
 
-    inline batch<int32_t, 16>& batch<int32_t, 16>::load_unaligned(const char* src)
+    inline batch<int32_t, 16>& batch<int32_t, 16>::load_unaligned(const int8_t* src)
     {
         __m128i tmp = _mm_loadu_si128((const __m128i*)src);
         m_value = _mm512_cvtepi8_epi32(tmp);
         return *this;
     }
 
-    inline batch<int32_t, 16>& batch<int32_t, 16>::load_aligned(const unsigned char* src)
+    inline batch<int32_t, 16>& batch<int32_t, 16>::load_aligned(const uint8_t* src)
     {
         __m128i tmp = _mm_load_si128((const __m128i*)src);
         m_value = _mm512_cvtepu8_epi32(tmp);
         return *this;
     }
 
-    inline batch<int32_t, 16>& batch<int32_t, 16>::load_unaligned(const unsigned char* src)
+    inline batch<int32_t, 16>& batch<int32_t, 16>::load_unaligned(const uint8_t* src)
     {
         __m128i tmp = _mm_loadu_si128((const __m128i*)src);
         m_value = _mm512_cvtepu8_epi32(tmp);
@@ -337,25 +345,25 @@ namespace xsimd
         _mm512_store_pd(dst + 8 , _mm512_cvtepi32_pd(tmp2));
     }
 
-    inline void batch<int32_t, 16>::store_aligned(char* dst) const
+    inline void batch<int32_t, 16>::store_aligned(int8_t* dst) const
     {
         __m128i tmp = _mm512_cvtepi32_epi8(m_value);
         _mm_store_si128((__m128i*)dst, tmp);
     }
 
-    inline void batch<int32_t, 16>::store_unaligned(char* dst) const
+    inline void batch<int32_t, 16>::store_unaligned(int8_t* dst) const
     {
         __m128i tmp = _mm512_cvtepi32_epi8(m_value);
         _mm_storeu_si128((__m128i*)dst, tmp);
     }
 
-    inline void batch<int32_t, 16>::store_aligned(unsigned char* dst) const
+    inline void batch<int32_t, 16>::store_aligned(uint8_t* dst) const
     {
         __m128i tmp = _mm512_cvtusepi32_epi8(m_value);
         _mm_store_si128((__m128i*)dst, tmp);
     }
 
-    inline void batch<int32_t, 16>::store_unaligned(unsigned char* dst) const
+    inline void batch<int32_t, 16>::store_unaligned(uint8_t* dst) const
     {
         __m128i tmp = _mm512_cvtusepi32_epi8(m_value);
         _mm_storeu_si128((__m128i*)dst, tmp);
