@@ -33,6 +33,9 @@ namespace xsimd
         using simd_type = float32x4_t;
     public:
 
+        using self_type = batch<float, 4>;
+        using base_type = simd_batch<self_type>;
+
         batch();
         explicit batch(float d);
         batch(float d0, float d1, float d2, float d3);
@@ -58,11 +61,11 @@ namespace xsimd
         batch& load_aligned(const int64_t* src);
         batch& load_unaligned(const int64_t* src);
 
-        batch& load_aligned(const char* src);
-        batch& load_unaligned(const char* src);
+        batch& load_aligned(const int8_t* src);
+        batch& load_unaligned(const int8_t* src);
 
-        batch& load_aligned(const unsigned char* src);
-        batch& load_unaligned(const unsigned char* src);
+        batch& load_aligned(const uint8_t* src);
+        batch& load_unaligned(const uint8_t* src);
 
         void store_aligned(float* dst) const;
         void store_unaligned(float* dst) const;
@@ -76,11 +79,16 @@ namespace xsimd
         void store_aligned(int64_t* dst) const;
         void store_unaligned(int64_t* dst) const;
 
-        void store_aligned(char* dst) const;
-        void store_unaligned(char* dst) const;
+        void store_aligned(int8_t* dst) const;
+        void store_unaligned(int8_t* dst) const;
 
-        void store_aligned(unsigned char* dst) const;
-        void store_unaligned(unsigned char* dst) const;
+        void store_aligned(uint8_t* dst) const;
+        void store_unaligned(uint8_t* dst) const;
+
+        using base_type::load_aligned;
+        using base_type::load_unaligned;
+        using base_type::store_aligned;
+        using base_type::store_unaligned;
 
         float operator[](std::size_t index) const;
 
@@ -210,7 +218,7 @@ namespace xsimd
         return load_aligned(d);
     }
 
-    inline batch<float, 4>& batch<float, 4>::load_aligned(const char* src)
+    inline batch<float, 4>& batch<float, 4>::load_aligned(const int8_t* src)
     {
         int8x8_t tmp = vld1_s8((const int8_t*)src);
         int16x8_t tmp2 = vmovl_s8(tmp);
@@ -220,12 +228,12 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<float, 4>& batch<float, 4>::load_unaligned(const char* src)
+    inline batch<float, 4>& batch<float, 4>::load_unaligned(const int8_t* src)
     {
         return load_aligned(src);
     }
 
-    inline batch<float, 4>& batch<float, 4>::load_aligned(const unsigned char* src)
+    inline batch<float, 4>& batch<float, 4>::load_aligned(const uint8_t* src)
     {
         uint8x8_t tmp = vld1_u8((const uint8_t*)src);
         uint16x8_t tmp2 = vmovl_u8(tmp);
@@ -235,7 +243,7 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<float, 4>& batch<float, 4>::load_unaligned(const unsigned char* src)
+    inline batch<float, 4>& batch<float, 4>::load_unaligned(const uint8_t* src)
     {
         return load_aligned(src);
     }
@@ -290,7 +298,7 @@ namespace xsimd
         store_aligned(dst);
     }
 
-    inline void batch<float, 4>::store_aligned(char* dst) const
+    inline void batch<float, 4>::store_aligned(int8_t* dst) const
     {
         int32x4_t tmp = vcvtq_s32_f32(m_value);
         int16x4_t tmp2 = vmovn_s32(tmp);
@@ -299,12 +307,12 @@ namespace xsimd
         vst1_s8((int8_t*)dst, tmp4);
     }
 
-    inline void batch<float, 4>::store_unaligned(char* dst) const
+    inline void batch<float, 4>::store_unaligned(int8_t* dst) const
     {
         store_unaligned(dst);
     }
 
-    inline void batch<float, 4>::store_aligned(unsigned char* dst) const
+    inline void batch<float, 4>::store_aligned(uint8_t* dst) const
     {
         uint32x4_t tmp = vcvtq_u32_f32(m_value);
         uint16x4_t tmp2 = vmovn_u32(tmp);
@@ -313,7 +321,7 @@ namespace xsimd
         vst1_u8((uint8_t*)dst, tmp4);
     }
 
-    inline void batch<float, 4>::store_unaligned(unsigned char* dst) const
+    inline void batch<float, 4>::store_unaligned(uint8_t* dst) const
     {
         store_aligned(dst);
     }
