@@ -65,6 +65,9 @@ namespace xsimd
     {
     public:
 
+        using self_type = batch<double, 2>;
+        using base_type = simd_batch<self_type>;
+
         batch();
         explicit batch(double d);
         batch(double d0, double d1);
@@ -88,11 +91,11 @@ namespace xsimd
         batch& load_aligned(const int64_t* src);
         batch& load_unaligned(const int64_t* src);
 
-        batch& load_aligned(const char* src);
-        batch& load_unaligned(const char* src);
+        batch& load_aligned(const int8_t* src);
+        batch& load_unaligned(const int8_t* src);
 
-        batch& load_aligned(const unsigned char* src);
-        batch& load_unaligned(const unsigned char* src);
+        batch& load_aligned(const uint8_t* src);
+        batch& load_unaligned(const uint8_t* src);
 
         void store_aligned(double* dst) const;
         void store_unaligned(double* dst) const;
@@ -106,11 +109,16 @@ namespace xsimd
         void store_aligned(int64_t* dst) const;
         void store_unaligned(int64_t* dst) const;
 
-        void store_aligned(char* dst) const;
-        void store_unaligned(char* dst) const;
+        void store_aligned(int8_t* dst) const;
+        void store_unaligned(int8_t* dst) const;
 
-        void store_aligned(unsigned char* dst) const;
-        void store_unaligned(unsigned char* dst) const;
+        void store_aligned(uint8_t* dst) const;
+        void store_unaligned(uint8_t* dst) const;
+
+        using base_type::load_aligned;
+        using base_type::load_unaligned;
+        using base_type::store_aligned;
+        using base_type::store_unaligned;
 
         double operator[](std::size_t index) const;
 
@@ -317,7 +325,7 @@ namespace xsimd
         return load_aligned(src);
     }
 
-    inline batch<double, 2>& batch<double, 2>::load_aligned(const char* src)
+    inline batch<double, 2>& batch<double, 2>::load_aligned(const int8_t* src)
     {
         __m128i tmp = _mm_loadl_epi64((const __m128i*)src);
 #if XSIMD_X86_INSTR_SET >= XSIMD_X86_SSE4_1_VERSION
@@ -332,12 +340,12 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<double, 2>& batch<double, 2>::load_unaligned(const char* src)
+    inline batch<double, 2>& batch<double, 2>::load_unaligned(const int8_t* src)
     {
         return load_aligned(src);
     }
 
-    inline batch<double, 2>& batch<double, 2>::load_aligned(const unsigned char* src)
+    inline batch<double, 2>& batch<double, 2>::load_aligned(const uint8_t* src)
     {
         __m128i tmp = _mm_loadl_epi64((const __m128i*)src);
 #if XSIMD_X86_INSTR_SET >= XSIMD_X86_SSE4_1_VERSION
@@ -350,7 +358,7 @@ namespace xsimd
         return *this;
     }
     
-    inline batch<double, 2>& batch<double, 2>::load_unaligned(const unsigned char* src)
+    inline batch<double, 2>& batch<double, 2>::load_unaligned(const uint8_t* src)
     {
         return load_aligned(src);
     }
@@ -404,7 +412,7 @@ namespace xsimd
         store_aligned(dst);
     }
 
-    inline void batch<double, 2>::store_aligned(char* dst) const
+    inline void batch<double, 2>::store_aligned(int8_t* dst) const
     {
         __m128i tmp = _mm_cvtpd_epi32(m_value);
         __m128i tmp1 = _mm_packs_epi32(tmp, tmp);
@@ -412,12 +420,12 @@ namespace xsimd
         _mm_storel_epi64((__m128i*)dst, tmp2);
     }
 
-    inline void batch<double, 2>::store_unaligned(char* dst) const
+    inline void batch<double, 2>::store_unaligned(int8_t* dst) const
     {
         store_aligned(dst);
     }
 
-    inline void batch<double, 2>::store_aligned(unsigned char* dst) const
+    inline void batch<double, 2>::store_aligned(uint8_t* dst) const
     {
         __m128i tmp = _mm_cvtpd_epi32(m_value);
         __m128i tmp1 = _mm_packs_epi32(tmp, tmp);
@@ -425,7 +433,7 @@ namespace xsimd
         _mm_storel_epi64((__m128i*)dst, tmp2);
     }
 
-    inline void batch<double, 2>::store_unaligned(unsigned char* dst) const
+    inline void batch<double, 2>::store_unaligned(uint8_t* dst) const
     {
         store_aligned(dst);
     }
