@@ -67,6 +67,9 @@ namespace xsimd
     {
     public:
 
+        using self_type = batch<int32_t, 4>;
+        using base_type = simd_batch<self_type>;
+
         batch();
         explicit batch(int32_t i);
         batch(int32_t i0, int32_t i1, int32_t i2, int32_t i3);
@@ -96,11 +99,11 @@ namespace xsimd
         void store_aligned(int64_t* dst) const;
         void store_unaligned(int64_t* dst) const;
 
-        batch& load_aligned(const char* src);
-        batch& load_unaligned(const char* src);
+        batch& load_aligned(const int8_t* src);
+        batch& load_unaligned(const int8_t* src);
 
-        batch& load_aligned(const unsigned char* src);
-        batch& load_unaligned(const unsigned char* src);
+        batch& load_aligned(const uint8_t* src);
+        batch& load_unaligned(const uint8_t* src);
 
         void store_aligned(float* dst) const;
         void store_unaligned(float* dst) const;
@@ -108,11 +111,16 @@ namespace xsimd
         void store_aligned(double* dst) const;
         void store_unaligned(double* dst) const;
 
-        void store_aligned(char* dst) const;
-        void store_unaligned(char* dst) const;
+        void store_aligned(int8_t* dst) const;
+        void store_unaligned(int8_t* dst) const;
 
-        void store_aligned(unsigned char* dst) const;
-        void store_unaligned(unsigned char* dst) const;
+        void store_aligned(uint8_t* dst) const;
+        void store_unaligned(uint8_t* dst) const;
+
+        using base_type::load_aligned;
+        using base_type::load_unaligned;
+        using base_type::store_aligned;
+        using base_type::store_unaligned;
 
         int32_t operator[](std::size_t index) const;
 
@@ -327,7 +335,7 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int32_t, 4>& batch<int32_t, 4>::load_aligned(const char* src)
+    inline batch<int32_t, 4>& batch<int32_t, 4>::load_aligned(const int8_t* src)
     {
         __m128i tmp = _mm_loadl_epi64((const __m128i*)src);
 #if XSIMD_X86_INSTR_SET >= XSIMD_X86_SSE4_1_VERSION
@@ -341,12 +349,12 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int32_t, 4>& batch<int32_t, 4>::load_unaligned(const char* src)
+    inline batch<int32_t, 4>& batch<int32_t, 4>::load_unaligned(const int8_t* src)
     {
         return load_aligned(src);
     }
 
-    inline batch<int32_t, 4>& batch<int32_t, 4>::load_aligned(const unsigned char* src)
+    inline batch<int32_t, 4>& batch<int32_t, 4>::load_aligned(const uint8_t* src)
     {
         __m128i tmp = _mm_loadl_epi64((const __m128i*)src);
 #if XSIMD_X86_INSTR_SET >= XSIMD_X86_SSE4_1_VERSION
@@ -358,7 +366,7 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int32_t, 4>& batch<int32_t, 4>::load_unaligned(const unsigned char* src)
+    inline batch<int32_t, 4>& batch<int32_t, 4>::load_unaligned(const uint8_t* src)
     {
         return load_aligned(src);
     }
@@ -414,26 +422,26 @@ namespace xsimd
         _mm_storeu_pd(dst + 2, tmp2);
     }
 
-    inline void batch<int32_t, 4>::store_aligned(char* dst) const
+    inline void batch<int32_t, 4>::store_aligned(int8_t* dst) const
     {
         __m128i tmp1 = _mm_packs_epi32(m_value, m_value);
         __m128i tmp2 = _mm_packs_epi16(tmp1, tmp1);
         _mm_storel_epi64((__m128i*)dst, tmp2);
     }
 
-    inline void batch<int32_t, 4>::store_unaligned(char* dst) const
+    inline void batch<int32_t, 4>::store_unaligned(int8_t* dst) const
     {
         store_aligned(dst);
     }
 
-    inline void batch<int32_t, 4>::store_aligned(unsigned char* dst) const
+    inline void batch<int32_t, 4>::store_aligned(uint8_t* dst) const
     {
         __m128i tmp1 = _mm_packs_epi32(m_value, m_value);
         __m128i tmp2 = _mm_packus_epi16(tmp1, tmp1);
         _mm_storel_epi64((__m128i*)dst, tmp2);
     }
 
-    inline void batch<int32_t, 4>::store_unaligned(unsigned char* dst) const
+    inline void batch<int32_t, 4>::store_unaligned(uint8_t* dst) const
     {
         store_aligned(dst);
     }
