@@ -67,6 +67,9 @@ namespace xsimd
     {
     public:
 
+        using self_type = batch<int64_t, 2>;
+        using base_type = simd_batch<self_type>;
+
         batch();
         explicit batch(int64_t i);
         batch(int64_t i0, int64_t i1);
@@ -90,11 +93,11 @@ namespace xsimd
         batch& load_aligned(const double* src);
         batch& load_unaligned(const double* src);
 
-        batch& load_aligned(const char* src);
-        batch& load_unaligned(const char* src);
+        batch& load_aligned(const int8_t* src);
+        batch& load_unaligned(const int8_t* src);
 
-        batch& load_aligned(const unsigned char* src);
-        batch& load_unaligned(const unsigned char* src);
+        batch& load_aligned(const uint8_t* src);
+        batch& load_unaligned(const uint8_t* src);
 
         void store_aligned(int64_t* dst) const;
         void store_unaligned(int64_t* dst) const;
@@ -108,11 +111,16 @@ namespace xsimd
         void store_aligned(double* dst) const;
         void store_unaligned(double* dst) const;
 
-        void store_aligned(char* dst) const;
-        void store_unaligned(char* dst) const;
+        void store_aligned(int8_t* dst) const;
+        void store_unaligned(int8_t* dst) const;
 
-        void store_aligned(unsigned char* dst) const;
-        void store_unaligned(unsigned char* dst) const;
+        void store_aligned(uint8_t* dst) const;
+        void store_unaligned(uint8_t* dst) const;
+
+        using base_type::load_aligned;
+        using base_type::load_unaligned;
+        using base_type::store_aligned;
+        using base_type::store_unaligned;
 
         int64_t operator[](std::size_t index) const;
 
@@ -347,7 +355,7 @@ namespace xsimd
     }
 
 
-    inline batch<int64_t, 2>& batch<int64_t, 2>::load_aligned(const char* src)
+    inline batch<int64_t, 2>& batch<int64_t, 2>::load_aligned(const int8_t* src)
     {
         __m128i tmp = _mm_loadl_epi64((const __m128i*)src);
 #if XSIMD_X86_INSTR_SET >= XSIMD_X86_SSE4_1_VERSION
@@ -363,12 +371,12 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int64_t, 2>& batch<int64_t, 2>::load_unaligned(const char* src)
+    inline batch<int64_t, 2>& batch<int64_t, 2>::load_unaligned(const int8_t* src)
     {
         return load_aligned(src);
     }
 
-    inline batch<int64_t, 2>& batch<int64_t, 2>::load_aligned(const unsigned char* src)
+    inline batch<int64_t, 2>& batch<int64_t, 2>::load_aligned(const uint8_t* src)
     {
         __m128i tmp = _mm_loadl_epi64((const __m128i*)src);
 #if XSIMD_X86_INSTR_SET >= XSIMD_X86_SSE4_1_VERSION
@@ -381,7 +389,7 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int64_t, 2>& batch<int64_t, 2>::load_unaligned(const unsigned char* src)
+    inline batch<int64_t, 2>& batch<int64_t, 2>::load_unaligned(const uint8_t* src)
     {
         return load_aligned(src);
     }
@@ -435,7 +443,7 @@ namespace xsimd
         store_aligned(dst);
     }
 
-    inline void batch<int64_t, 2>::store_aligned(char* dst) const
+    inline void batch<int64_t, 2>::store_aligned(int8_t* dst) const
     {
         alignas(16) int64_t tmp[2];
         store_aligned(tmp);
@@ -443,12 +451,12 @@ namespace xsimd
         dst[1] = static_cast<char>(tmp[1]);
     }
 
-    inline void batch<int64_t, 2>::store_unaligned(char* dst) const
+    inline void batch<int64_t, 2>::store_unaligned(int8_t* dst) const
     {
         store_aligned(dst);
     }
 
-    inline void batch<int64_t, 2>::store_aligned(unsigned char* dst) const
+    inline void batch<int64_t, 2>::store_aligned(uint8_t* dst) const
     {
         alignas(16) int64_t tmp[2];
         store_aligned(tmp);
@@ -456,7 +464,7 @@ namespace xsimd
         dst[1] = static_cast<unsigned char>(tmp[1]);
     }
 
-    inline void batch<int64_t, 2>::store_unaligned(unsigned char* dst) const
+    inline void batch<int64_t, 2>::store_unaligned(uint8_t* dst) const
     {
         store_aligned(dst);
     }
